@@ -9,4 +9,4 @@ TEMPLATE_DIRS = os.path.join(os.path.dirname(__file__), 'tests', 'templates')
 
 FOURSTORE_KBNAME = "django_4store"
 FOURSTORE_PORT = 8666
-SPARQL_ENDPOINT = "http://localhost:%d" % FOURSTORE_PORT
+SPARQL_ENDPOINT = "http://localhost:%d/sparql/" % FOURSTORE_PORT
